/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED BY BPFTOOL! */
#ifndef __KFREE_SKB_SKEL_H__
#define __KFREE_SKB_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

#define BPF_SKEL_SUPPORTS_MAP_AUTO_ATTACH 1

struct kfree_skb {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *perf_buf_map;
		struct bpf_map *bss;
		struct bpf_map *rodata;
	} maps;
	struct {
		struct bpf_program *trace_kfree_skb;
		struct bpf_program *fentry_eth_type_trans;
		struct bpf_program *fexit_eth_type_trans;
	} progs;
	struct {
		struct bpf_link *trace_kfree_skb;
		struct bpf_link *fentry_eth_type_trans;
		struct bpf_link *fexit_eth_type_trans;
	} links;
	struct kfree_skb__bss {
		struct {
			_Bool fentry_test_ok;
			_Bool fexit_test_ok;
		} result;
	} *bss;

#ifdef __cplusplus
	static inline struct kfree_skb *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct kfree_skb *open_and_load();
	static inline int load(struct kfree_skb *skel);
	static inline int attach(struct kfree_skb *skel);
	static inline void detach(struct kfree_skb *skel);
	static inline void destroy(struct kfree_skb *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
kfree_skb__destroy(struct kfree_skb *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
kfree_skb__create_skeleton(struct kfree_skb *obj);

static inline struct kfree_skb *
kfree_skb__open_opts(const struct bpf_object_open_opts *opts)
{
	struct kfree_skb *obj;
	int err;

	obj = (struct kfree_skb *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = kfree_skb__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	kfree_skb__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct kfree_skb *
kfree_skb__open(void)
{
	return kfree_skb__open_opts(NULL);
}

static inline int
kfree_skb__load(struct kfree_skb *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct kfree_skb *
kfree_skb__open_and_load(void)
{
	struct kfree_skb *obj;
	int err;

	obj = kfree_skb__open();
	if (!obj)
		return NULL;
	err = kfree_skb__load(obj);
	if (err) {
		kfree_skb__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
kfree_skb__attach(struct kfree_skb *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
kfree_skb__detach(struct kfree_skb *obj)
{
	bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *kfree_skb__elf_bytes(size_t *sz);

static inline int
kfree_skb__create_skeleton(struct kfree_skb *obj)
{
	struct bpf_object_skeleton *s;
	struct bpf_map_skeleton *map __attribute__((unused));
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "kfree_skb";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 3;
	s->map_skel_sz = 24;
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt,
			sizeof(*s->maps) > 24 ? sizeof(*s->maps) : 24);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	map = (struct bpf_map_skeleton *)((char *)s->maps + 0 * s->map_skel_sz);
	map->name = "perf_buf_map";
	map->map = &obj->maps.perf_buf_map;

	map = (struct bpf_map_skeleton *)((char *)s->maps + 1 * s->map_skel_sz);
	map->name = "kfree_sk.bss";
	map->map = &obj->maps.bss;
	map->mmaped = (void **)&obj->bss;

	map = (struct bpf_map_skeleton *)((char *)s->maps + 2 * s->map_skel_sz);
	map->name = "kfree_sk.rodata";
	map->map = &obj->maps.rodata;

	/* programs */
	s->prog_cnt = 3;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "trace_kfree_skb";
	s->progs[0].prog = &obj->progs.trace_kfree_skb;
	s->progs[0].link = &obj->links.trace_kfree_skb;

	s->progs[1].name = "fentry_eth_type_trans";
	s->progs[1].prog = &obj->progs.fentry_eth_type_trans;
	s->progs[1].link = &obj->links.fentry_eth_type_trans;

	s->progs[2].name = "fexit_eth_type_trans";
	s->progs[2].prog = &obj->progs.fexit_eth_type_trans;
	s->progs[2].link = &obj->links.fexit_eth_type_trans;

	s->data = kfree_skb__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *kfree_skb__elf_bytes(size_t *sz)
{
	static const char data[] __attribute__((__aligned__(8))) = "\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x20\x19\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0f\0\
\x01\0\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x74\x70\
\x5f\x62\x74\x66\x2f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\0\x66\x65\x6e\x74\x72\
\x79\x2f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\0\x66\x65\x78\
\x69\x74\x2f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\0\x6c\x69\
\x63\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\x2e\x6d\x61\x70\x73\0\x2e\x72\x6f\x64\
\x61\x74\x61\0\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x63\0\x5f\x5f\x5f\x5f\
\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\
\x5f\x66\x6d\x74\0\x5f\x5f\x5f\x5f\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\
\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\x74\x2e\x31\0\x5f\x5f\x5f\x5f\x74\
\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\
\x66\x6d\x74\x2e\x32\0\x5f\x5f\x5f\x5f\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\
\x65\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\x74\x2e\x33\0\x5f\x5f\x5f\x5f\
\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\
\x5f\x66\x6d\x74\x2e\x34\0\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\
\x6b\x62\0\x70\x65\x72\x66\x5f\x62\x75\x66\x5f\x6d\x61\x70\0\x66\x65\x6e\x74\
\x72\x79\x5f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\0\x72\x65\
\x73\x75\x6c\x74\0\x66\x65\x78\x69\x74\x5f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\
\x74\x72\x61\x6e\x73\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\x74\
\x70\x5f\x62\x74\x66\x2f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\0\x2e\x72\x65\x6c\
\x66\x65\x6e\x74\x72\x79\x2f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\
\x6e\x73\0\x2e\x72\x65\x6c\x66\x65\x78\x69\x74\x2f\x65\x74\x68\x5f\x74\x79\x70\
\x65\x5f\x74\x72\x61\x6e\x73\0\x2e\x42\x54\x46\0\x2e\x42\x54\x46\x2e\x65\x78\
\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x68\0\0\0\x04\0\xf1\
\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x74\0\0\0\x01\0\x09\0\0\0\0\0\0\0\0\0\x1d\0\0\0\0\0\0\0\x90\0\0\0\
\x01\0\x09\0\x1d\0\0\0\0\0\0\0\x22\0\0\0\0\0\0\0\xae\0\0\0\x01\0\x09\0\x3f\0\0\
\0\0\0\0\0\x17\0\0\0\0\0\0\0\xcc\0\0\0\x01\0\x09\0\x56\0\0\0\0\0\0\0\x27\0\0\0\
\0\0\0\0\xea\0\0\0\x01\0\x09\0\x7d\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\0\0\0\0\x03\
\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x05\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x03\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x01\0\0\
\x12\0\x03\0\0\0\0\0\0\0\0\0\xa0\x02\0\0\0\0\0\0\x18\x01\0\0\x11\0\x08\0\0\0\0\
\0\0\0\0\0\x18\0\0\0\0\0\0\0\x25\x01\0\0\x12\0\x04\0\0\0\0\0\0\0\0\0\x58\0\0\0\
\0\0\0\0\x3b\x01\0\0\x11\0\x07\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\x42\x01\0\0\
\x12\0\x05\0\0\0\0\0\0\0\0\0\x70\0\0\0\0\0\0\0\x57\x01\0\0\x11\0\x06\0\0\0\0\0\
\0\0\0\0\x04\0\0\0\0\0\0\0\x79\x16\0\0\0\0\0\0\x62\x0a\xf8\xff\0\0\0\0\x79\x61\
\x10\0\0\0\0\0\x79\x12\x08\0\0\0\0\0\xb7\x03\0\0\x28\0\0\0\x61\x64\x18\0\0\0\0\
\0\x63\x4a\xd8\xff\0\0\0\0\x79\x69\x20\0\0\0\0\0\xbf\x64\0\0\0\0\0\0\x0f\x34\0\
\0\0\0\0\0\x79\x28\0\0\0\0\0\0\x79\x82\x08\0\0\0\0\0\x7b\x2a\xd0\xff\0\0\0\0\
\x61\x17\0\0\0\0\0\0\x63\x7a\xf0\xff\0\0\0\0\x71\x41\x08\0\0\0\0\0\x63\x1a\xe8\
\xff\0\0\0\0\x73\x1a\xf8\xff\0\0\0\0\x61\x41\x08\0\0\0\0\0\x63\x1a\xe0\xff\0\0\
\0\0\x63\x1a\xf4\xff\0\0\0\0\xb7\x01\0\0\x28\0\0\0\xbf\x63\0\0\0\0\0\0\x0f\x13\
\0\0\0\0\0\0\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\xef\xff\xff\xff\xb4\x02\0\0\x01\0\
\0\0\x85\0\0\0\x71\0\0\0\x71\xa1\xef\xff\0\0\0\0\x54\x01\0\0\x07\0\0\0\x73\x1a\
\xef\xff\0\0\0\0\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\xfe\xff\xff\xff\xbf\x93\0\0\0\
\0\0\0\x07\x03\0\0\x0c\0\0\0\xb4\x02\0\0\x02\0\0\0\x85\0\0\0\x71\0\0\0\x18\x01\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb4\x02\0\0\x1d\0\0\0\xbf\x83\0\0\0\0\0\0\x79\xa4\
\xd0\xff\0\0\0\0\x85\0\0\0\x06\0\0\0\x61\x63\0\0\0\0\0\0\x91\xa5\xef\xff\0\0\0\
\0\x18\x01\0\0\x1d\0\0\0\0\0\0\0\0\0\0\0\xb4\x02\0\0\x22\0\0\0\x61\xa8\xd8\xff\
\0\0\0\0\xbc\x84\0\0\0\0\0\0\x85\0\0\0\x06\0\0\0\x69\x63\x0c\0\0\0\0\0\x18\x01\
\0\0\x3f\0\0\0\0\0\0\0\0\0\0\0\xb4\x02\0\0\x17\0\0\0\x85\0\0\0\x06\0\0\0\x69\
\xa5\xfe\xff\0\0\0\0\x18\x01\0\0\x56\0\0\0\0\0\0\0\0\0\0\0\xb4\x02\0\0\x27\0\0\
\0\xbc\x73\0\0\0\0\0\0\xbf\x94\0\0\0\0\0\0\x85\0\0\0\x06\0\0\0\x18\x01\0\0\x7d\
\0\0\0\0\0\0\0\0\0\0\0\xb4\x02\0\0\x14\0\0\0\x61\xa3\xe8\xff\0\0\0\0\x61\xa4\
\xe0\xff\0\0\0\0\x85\0\0\0\x06\0\0\0\x56\x08\x0c\0\x01\0\0\0\x69\xa1\xfe\xff\0\
\0\0\0\x56\x01\x0a\0\x86\xdd\0\0\x56\x07\x09\0\x01\0\0\0\xbf\xa4\0\0\0\0\0\0\
\x07\x04\0\0\xf0\xff\xff\xff\xbf\x61\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x18\x03\0\0\xff\xff\xff\xff\0\0\0\0\x48\0\0\0\xb7\x05\0\0\x0c\0\0\0\x85\
\0\0\0\x6f\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x12\0\0\0\0\0\0\x79\
\x11\x08\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x61\x22\0\0\0\0\0\0\x56\x02\x04\0\x4a\0\
\0\0\x56\x01\x03\0\x01\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x72\x01\0\0\
\x01\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x13\0\0\0\0\0\0\x79\x12\x08\
\0\0\0\0\0\x61\x22\0\0\0\0\0\0\x61\x33\0\0\0\0\0\0\x79\x11\x10\0\0\0\0\0\x57\
\x01\0\0\xff\xff\0\0\x55\x01\x05\0\x86\xdd\0\0\x56\x03\x04\0\x3c\0\0\0\x56\x02\
\x03\0\x01\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x72\x01\x01\0\x01\0\0\0\
\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x72\x63\x75\x68\x65\x61\x64\x2e\x6e\x65\x78\x74\
\x20\x25\x6c\x6c\x78\x20\x66\x75\x6e\x63\x20\x25\x6c\x6c\x78\x0a\0\x73\x6b\x62\
\x2d\x3e\x6c\x65\x6e\x20\x25\x64\x20\x75\x73\x65\x72\x73\x20\x25\x64\x20\x70\
\x6b\x74\x5f\x74\x79\x70\x65\x20\x25\x78\x0a\0\x73\x6b\x62\x2d\x3e\x71\x75\x65\
\x75\x65\x5f\x6d\x61\x70\x70\x69\x6e\x67\x20\x25\x64\x0a\0\x64\x65\x76\x2d\x3e\
\x69\x66\x69\x6e\x64\x65\x78\x20\x25\x64\x20\x64\x61\x74\x61\x20\x25\x6c\x6c\
\x78\x20\x70\x6b\x74\x5f\x64\x61\x74\x61\x20\x25\x78\x0a\0\x63\x62\x38\x5f\x30\
\x3a\x25\x78\x20\x63\x62\x33\x32\x5f\x30\x3a\x25\x78\x0a\0\0\0\0\0\0\0\0\x28\
\x01\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\x68\x01\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\
\xa0\x01\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\xc8\x01\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\
\0\xf8\x01\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\x60\x02\0\0\0\0\0\0\x01\0\0\0\x0c\0\
\0\0\x30\0\0\0\0\0\0\0\x01\0\0\0\x0e\0\0\0\x48\0\0\0\0\0\0\0\x01\0\0\0\x0e\0\0\
\0\x9f\xeb\x01\0\x18\0\0\0\0\0\0\0\xac\x04\0\0\xac\x04\0\0\x3c\x08\0\0\0\0\0\0\
\0\0\0\x02\x03\0\0\0\x01\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\0\0\0\0\0\0\0\
\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x04\0\0\0\x05\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\
\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\x03\0\0\x04\x18\0\0\0\x19\0\0\0\x01\0\
\0\0\0\0\0\0\x1e\0\0\0\x05\0\0\0\x40\0\0\0\x22\0\0\0\x05\0\0\0\x80\0\0\0\x28\0\
\0\0\0\0\0\x0e\x06\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x09\0\0\0\x35\0\0\0\0\0\0\
\x01\x08\0\0\0\x40\0\0\0\0\0\0\0\x01\0\0\x0d\x02\0\0\0\x48\0\0\0\x08\0\0\0\x4c\
\0\0\0\x01\0\0\x0c\x0a\0\0\0\x5c\0\0\0\x0a\0\0\x04\x58\0\0\0\x64\0\0\0\x0d\0\0\
\0\0\0\0\0\x68\0\0\0\x0d\0\0\0\x20\0\0\0\x71\0\0\0\x0e\0\0\0\x40\0\0\0\x79\0\0\
\0\x0e\0\0\0\x50\0\0\0\x81\0\0\0\x0e\0\0\0\x60\0\0\0\x8f\0\0\0\x10\0\0\0\x80\0\
\0\0\x93\0\0\0\x11\0\0\0\xc0\0\0\0\x99\0\0\0\x15\0\0\0\0\x01\0\0\x9e\0\0\0\x18\
\0\0\0\x40\x01\0\0\xb0\0\0\0\x19\0\0\0\x40\x01\0\0\xb3\0\0\0\0\0\0\x01\x04\0\0\
\0\x20\0\0\0\xc0\0\0\0\0\0\0\x08\x0f\0\0\0\xc6\0\0\0\0\0\0\x01\x02\0\0\0\x10\0\
\0\0\0\0\0\0\0\0\0\x02\x1a\0\0\0\xd5\0\0\0\0\0\0\x08\x12\0\0\0\xe0\0\0\0\x01\0\
\0\x04\x04\0\0\0\xf0\0\0\0\x13\0\0\0\0\0\0\0\xf5\0\0\0\0\0\0\x08\x14\0\0\0\0\0\
\0\0\x01\0\0\x04\x04\0\0\0\xfe\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x16\0\
\0\0\x06\x01\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\0\x14\x01\0\0\0\0\0\x01\x01\0\0\0\
\x08\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\x17\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x03\0\0\0\0\x17\0\0\0\x04\0\0\0\x30\0\0\0\x19\x01\0\0\x02\0\0\x04\x10\0\0\0\
\x24\x01\0\0\x02\0\0\0\0\0\0\0\x2c\x01\0\0\x1b\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\
\x02\x1c\0\0\0\x34\x01\0\0\x01\0\0\x04\x10\0\0\0\x40\x01\0\0\x1d\0\0\0\0\0\0\0\
\x48\x01\0\0\x02\0\0\x04\x10\0\0\0\x56\x01\0\0\x1e\0\0\0\0\0\0\0\x5b\x01\0\0\
\x1f\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x02\x1d\0\0\0\0\0\0\0\0\0\0\x02\x20\0\0\0\0\
\0\0\0\x01\0\0\x0d\0\0\0\0\0\0\0\0\x1e\0\0\0\x60\x01\0\0\x01\0\0\x0c\x0a\0\0\0\
\x76\x01\0\0\x01\0\0\x0c\x0a\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x17\0\0\0\x04\0\0\
\0\x04\0\0\0\x8b\x01\0\0\0\0\0\x0e\x23\0\0\0\x01\0\0\0\0\0\0\0\x02\0\0\x04\x02\
\0\0\0\x94\x01\0\0\x26\0\0\0\0\0\0\0\xa3\x01\0\0\x26\0\0\0\x08\0\0\0\xb1\x01\0\
\0\0\0\0\x01\x01\0\0\0\x08\0\0\x04\xb7\x01\0\0\0\0\0\x0e\x25\0\0\0\x01\0\0\0\0\
\0\0\0\0\0\0\x0a\x17\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x28\0\0\0\x04\0\0\0\x1d\0\
\0\0\xbe\x01\0\0\0\0\0\x0e\x29\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x28\0\0\
\0\x04\0\0\0\x22\0\0\0\xda\x01\0\0\0\0\0\x0e\x2b\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\0\0\x28\0\0\0\x04\0\0\0\x17\0\0\0\xf8\x01\0\0\0\0\0\x0e\x2d\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x28\0\0\0\x04\0\0\0\x27\0\0\0\x16\x02\0\0\0\0\0\
\x0e\x2f\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x28\0\0\0\x04\0\0\0\x14\0\0\0\
\x34\x02\0\0\0\0\0\x0e\x31\0\0\0\0\0\0\0\xe5\x07\0\0\x01\0\0\x0f\x04\0\0\0\x24\
\0\0\0\0\0\0\0\x04\0\0\0\xed\x07\0\0\x01\0\0\x0f\x02\0\0\0\x27\0\0\0\0\0\0\0\
\x02\0\0\0\xf2\x07\0\0\x01\0\0\x0f\x18\0\0\0\x07\0\0\0\0\0\0\0\x18\0\0\0\xf8\
\x07\0\0\x05\0\0\x0f\x91\0\0\0\x2a\0\0\0\0\0\0\0\x1d\0\0\0\x2c\0\0\0\x1d\0\0\0\
\x22\0\0\0\x2e\0\0\0\x3f\0\0\0\x17\0\0\0\x30\0\0\0\x56\0\0\0\x27\0\0\0\x32\0\0\
\0\x7d\0\0\0\x14\0\0\0\0\x69\x6e\x74\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\
\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x74\x79\x70\x65\0\x6b\x65\x79\0\x76\x61\
\x6c\x75\x65\0\x70\x65\x72\x66\x5f\x62\x75\x66\x5f\x6d\x61\x70\0\x75\x6e\x73\
\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x63\x74\x78\0\
\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\0\x73\x6b\x5f\x62\
\x75\x66\x66\0\x6c\x65\x6e\0\x64\x61\x74\x61\x5f\x6c\x65\x6e\0\x6d\x61\x63\x5f\
\x6c\x65\x6e\0\x68\x64\x72\x5f\x6c\x65\x6e\0\x71\x75\x65\x75\x65\x5f\x6d\x61\
\x70\x70\x69\x6e\x67\0\x64\x65\x76\0\x75\x73\x65\x72\x73\0\x64\x61\x74\x61\0\
\x5f\x5f\x70\x6b\x74\x5f\x74\x79\x70\x65\x5f\x6f\x66\x66\x73\x65\x74\0\x63\x62\
\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x5f\x5f\x75\x31\x36\0\x75\
\x6e\x73\x69\x67\x6e\x65\x64\x20\x73\x68\x6f\x72\x74\0\x72\x65\x66\x63\x6f\x75\
\x6e\x74\x5f\x74\0\x72\x65\x66\x63\x6f\x75\x6e\x74\x5f\x73\x74\x72\x75\x63\x74\
\0\x72\x65\x66\x73\0\x61\x74\x6f\x6d\x69\x63\x5f\x74\0\x63\x6f\x75\x6e\x74\x65\
\x72\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x63\x68\x61\x72\0\x63\x68\x61\x72\0\
\x6e\x65\x74\x5f\x64\x65\x76\x69\x63\x65\0\x69\x66\x69\x6e\x64\x65\x78\0\x69\
\x66\x61\x6c\x69\x61\x73\0\x64\x65\x76\x5f\x69\x66\x61\x6c\x69\x61\x73\0\x72\
\x63\x75\x68\x65\x61\x64\0\x63\x61\x6c\x6c\x62\x61\x63\x6b\x5f\x68\x65\x61\x64\
\0\x6e\x65\x78\x74\0\x66\x75\x6e\x63\0\x66\x65\x6e\x74\x72\x79\x5f\x65\x74\x68\
\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\0\x66\x65\x78\x69\x74\x5f\x65\x74\
\x68\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\0\x5f\x6c\x69\x63\x65\x6e\x73\
\x65\0\x66\x65\x6e\x74\x72\x79\x5f\x74\x65\x73\x74\x5f\x6f\x6b\0\x66\x65\x78\
\x69\x74\x5f\x74\x65\x73\x74\x5f\x6f\x6b\0\x5f\x42\x6f\x6f\x6c\0\x72\x65\x73\
\x75\x6c\x74\0\x5f\x5f\x5f\x5f\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\
\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\x74\0\x5f\x5f\x5f\x5f\x74\x72\x61\x63\
\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\x74\
\x2e\x31\0\x5f\x5f\x5f\x5f\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\
\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\x74\x2e\x32\0\x5f\x5f\x5f\x5f\x74\x72\x61\
\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\
\x74\x2e\x33\0\x5f\x5f\x5f\x5f\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\
\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\x74\x2e\x34\0\x2f\x62\x75\x69\x6c\x64\
\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\
\x6e\x65\x6c\x2d\x36\x2e\x31\x32\x2e\x30\x2d\x35\x35\x2e\x31\x32\x2e\x31\x2e\
\x65\x6c\x31\x30\x5f\x30\x2f\x6c\x69\x6e\x75\x78\x2d\x36\x2e\x31\x32\x2e\x30\
\x2d\x35\x35\x2e\x31\x32\x2e\x31\x2e\x65\x6c\x31\x30\x5f\x30\x2e\x70\x70\x63\
\x36\x34\x6c\x65\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\
\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\
\x2f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x63\0\x69\x6e\x74\x20\x42\x50\x46\
\x5f\x50\x52\x4f\x47\x28\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\
\x6b\x62\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x73\x6b\x5f\x62\x75\x66\x66\x20\
\x2a\x73\x6b\x62\x2c\x20\x76\x6f\x69\x64\x20\x2a\x6c\x6f\x63\x61\x74\x69\x6f\
\x6e\x29\0\x09\x73\x74\x72\x75\x63\x74\x20\x6d\x65\x74\x61\x20\x6d\x65\x74\x61\
\x20\x3d\x20\x7b\x7d\x3b\0\x09\x09\x64\x65\x76\x20\x3d\x20\x73\x6b\x62\x2d\x3e\
\x64\x65\x76\x3b\0\x09\x09\x70\x74\x72\x20\x3d\x20\x64\x65\x76\x2d\x3e\x69\x66\
\x61\x6c\x69\x61\x73\x2d\x3e\x72\x63\x75\x68\x65\x61\x64\x2e\x6e\x65\x78\x74\
\x3b\0\x09\x09\x75\x73\x65\x72\x73\x20\x3d\x20\x73\x6b\x62\x2d\x3e\x75\x73\x65\
\x72\x73\x2e\x72\x65\x66\x73\x2e\x63\x6f\x75\x6e\x74\x65\x72\x3b\0\x09\x09\x64\
\x61\x74\x61\x20\x3d\x20\x73\x6b\x62\x2d\x3e\x64\x61\x74\x61\x3b\0\x09\x09\x66\
\x75\x6e\x63\x20\x3d\x20\x70\x74\x72\x2d\x3e\x66\x75\x6e\x63\x3b\0\x09\x6d\x65\
\x74\x61\x2e\x69\x66\x69\x6e\x64\x65\x78\x20\x3d\x20\x5f\x28\x64\x65\x76\x2d\
\x3e\x69\x66\x69\x6e\x64\x65\x78\x29\x3b\0\x09\x6d\x65\x74\x61\x2e\x63\x62\x38\
\x5f\x30\x20\x3d\x20\x63\x62\x38\x5b\x38\x5d\x3b\0\x09\x6d\x65\x74\x61\x2e\x63\
\x62\x33\x32\x5f\x30\x20\x3d\x20\x63\x62\x33\x32\x5b\x32\x5d\x3b\0\x09\x62\x70\
\x66\x5f\x70\x72\x6f\x62\x65\x5f\x72\x65\x61\x64\x5f\x6b\x65\x72\x6e\x65\x6c\
\x28\x26\x70\x6b\x74\x5f\x74\x79\x70\x65\x2c\x20\x73\x69\x7a\x65\x6f\x66\x28\
\x70\x6b\x74\x5f\x74\x79\x70\x65\x29\x2c\x20\x5f\x28\x26\x73\x6b\x62\x2d\x3e\
\x5f\x5f\x70\x6b\x74\x5f\x74\x79\x70\x65\x5f\x6f\x66\x66\x73\x65\x74\x29\x29\
\x3b\0\x09\x70\x6b\x74\x5f\x74\x79\x70\x65\x20\x26\x3d\x20\x37\x3b\0\x09\x62\
\x70\x66\x5f\x70\x72\x6f\x62\x65\x5f\x72\x65\x61\x64\x5f\x6b\x65\x72\x6e\x65\
\x6c\x28\x26\x70\x6b\x74\x5f\x64\x61\x74\x61\x2c\x20\x73\x69\x7a\x65\x6f\x66\
\x28\x70\x6b\x74\x5f\x64\x61\x74\x61\x29\x2c\x20\x64\x61\x74\x61\x20\x2b\x20\
\x31\x32\x29\x3b\0\x09\x62\x70\x66\x5f\x70\x72\x69\x6e\x74\x6b\x28\x22\x72\x63\
\x75\x68\x65\x61\x64\x2e\x6e\x65\x78\x74\x20\x25\x6c\x6c\x78\x20\x66\x75\x6e\
\x63\x20\x25\x6c\x6c\x78\x5c\x6e\x22\x2c\x20\x70\x74\x72\x2c\x20\x66\x75\x6e\
\x63\x29\x3b\0\x09\x62\x70\x66\x5f\x70\x72\x69\x6e\x74\x6b\x28\x22\x73\x6b\x62\
\x2d\x3e\x6c\x65\x6e\x20\x25\x64\x20\x75\x73\x65\x72\x73\x20\x25\x64\x20\x70\
\x6b\x74\x5f\x74\x79\x70\x65\x20\x25\x78\x5c\x6e\x22\x2c\0\x09\x62\x70\x66\x5f\
\x70\x72\x69\x6e\x74\x6b\x28\x22\x73\x6b\x62\x2d\x3e\x71\x75\x65\x75\x65\x5f\
\x6d\x61\x70\x70\x69\x6e\x67\x20\x25\x64\x5c\x6e\x22\x2c\x20\x5f\x28\x73\x6b\
\x62\x2d\x3e\x71\x75\x65\x75\x65\x5f\x6d\x61\x70\x70\x69\x6e\x67\x29\x29\x3b\0\
\x09\x62\x70\x66\x5f\x70\x72\x69\x6e\x74\x6b\x28\x22\x64\x65\x76\x2d\x3e\x69\
\x66\x69\x6e\x64\x65\x78\x20\x25\x64\x20\x64\x61\x74\x61\x20\x25\x6c\x6c\x78\
\x20\x70\x6b\x74\x5f\x64\x61\x74\x61\x20\x25\x78\x5c\x6e\x22\x2c\0\x09\x62\x70\
\x66\x5f\x70\x72\x69\x6e\x74\x6b\x28\x22\x63\x62\x38\x5f\x30\x3a\x25\x78\x20\
\x63\x62\x33\x32\x5f\x30\x3a\x25\x78\x5c\x6e\x22\x2c\x20\x6d\x65\x74\x61\x2e\
\x63\x62\x38\x5f\x30\x2c\x20\x6d\x65\x74\x61\x2e\x63\x62\x33\x32\x5f\x30\x29\
\x3b\0\x09\x69\x66\x20\x28\x75\x73\x65\x72\x73\x20\x21\x3d\x20\x31\x20\x7c\x7c\
\x20\x70\x6b\x74\x5f\x64\x61\x74\x61\x20\x21\x3d\x20\x62\x70\x66\x5f\x68\x74\
\x6f\x6e\x73\x28\x30\x78\x38\x36\x64\x64\x29\x20\x7c\x7c\x20\x6d\x65\x74\x61\
\x2e\x69\x66\x69\x6e\x64\x65\x78\x20\x21\x3d\x20\x31\x29\0\x09\x62\x70\x66\x5f\
\x73\x6b\x62\x5f\x6f\x75\x74\x70\x75\x74\x28\x73\x6b\x62\x2c\x20\x26\x70\x65\
\x72\x66\x5f\x62\x75\x66\x5f\x6d\x61\x70\x2c\x20\x28\x37\x32\x75\x6c\x6c\x20\
\x3c\x3c\x20\x33\x32\x29\x20\x7c\x20\x42\x50\x46\x5f\x46\x5f\x43\x55\x52\x52\
\x45\x4e\x54\x5f\x43\x50\x55\x2c\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\
\x47\x28\x66\x65\x6e\x74\x72\x79\x5f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\x74\
\x72\x61\x6e\x73\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x73\x6b\x5f\x62\x75\x66\
\x66\x20\x2a\x73\x6b\x62\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x6e\x65\x74\x5f\
\x64\x65\x76\x69\x63\x65\x20\x2a\x64\x65\x76\x2c\0\x09\x09\x69\x66\x69\x6e\x64\
\x65\x78\x20\x3d\x20\x64\x65\x76\x2d\x3e\x69\x66\x69\x6e\x64\x65\x78\x3b\0\x09\
\x09\x6c\x65\x6e\x20\x3d\x20\x73\x6b\x62\x2d\x3e\x6c\x65\x6e\x3b\0\x09\x69\x66\
\x20\x28\x6c\x65\x6e\x20\x21\x3d\x20\x37\x34\x20\x7c\x7c\x20\x69\x66\x69\x6e\
\x64\x65\x78\x20\x21\x3d\x20\x31\x29\0\x09\x72\x65\x73\x75\x6c\x74\x2e\x66\x65\
\x6e\x74\x72\x79\x5f\x74\x65\x73\x74\x5f\x6f\x6b\x20\x3d\x20\x74\x72\x75\x65\
\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x66\x65\x78\x69\x74\
\x5f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\x2c\x20\x73\x74\
\x72\x75\x63\x74\x20\x73\x6b\x5f\x62\x75\x66\x66\x20\x2a\x73\x6b\x62\x2c\x20\
\x73\x74\x72\x75\x63\x74\x20\x6e\x65\x74\x5f\x64\x65\x76\x69\x63\x65\x20\x2a\
\x64\x65\x76\x2c\0\x09\x69\x66\x20\x28\x6c\x65\x6e\x20\x21\x3d\x20\x36\x30\x20\
\x7c\x7c\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x20\x21\x3d\x20\x62\x70\x66\x5f\
\x68\x74\x6f\x6e\x73\x28\x30\x78\x38\x36\x64\x64\x29\x20\x7c\x7c\x20\x69\x66\
\x69\x6e\x64\x65\x78\x20\x21\x3d\x20\x31\x29\0\x09\x72\x65\x73\x75\x6c\x74\x2e\
\x66\x65\x78\x69\x74\x5f\x74\x65\x73\x74\x5f\x6f\x6b\x20\x3d\x20\x74\x72\x75\
\x65\x3b\0\x30\x3a\x35\0\x30\x3a\x31\0\x30\x3a\x39\0\x30\x3a\x36\x3a\x30\x3a\
\x30\0\x30\x3a\x37\0\x30\x3a\x30\x3a\x30\0\x30\x3a\x30\0\x30\x3a\x38\0\x30\x3a\
\x34\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\x2e\x6d\x61\x70\x73\0\
\x2e\x72\x6f\x64\x61\x74\x61\0\x74\x70\x5f\x62\x74\x66\x2f\x6b\x66\x72\x65\x65\
\x5f\x73\x6b\x62\0\x66\x65\x6e\x74\x72\x79\x2f\x65\x74\x68\x5f\x74\x79\x70\x65\
\x5f\x74\x72\x61\x6e\x73\0\x66\x65\x78\x69\x74\x2f\x65\x74\x68\x5f\x74\x79\x70\
\x65\x5f\x74\x72\x61\x6e\x73\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x34\0\0\0\x34\0\
\0\0\x8c\x02\0\0\xc0\x02\0\0\x0c\x01\0\0\x08\0\0\0\0\x08\0\0\x01\0\0\0\0\0\0\0\
\x0b\0\0\0\x11\x08\0\0\x01\0\0\0\0\0\0\0\x21\0\0\0\x27\x08\0\0\x01\0\0\0\0\0\0\
\0\x22\0\0\0\x10\0\0\0\0\x08\0\0\x1a\0\0\0\0\0\0\0\x52\x02\0\0\xd7\x02\0\0\x05\
\xf4\0\0\x08\0\0\0\x52\x02\0\0\x1a\x03\0\0\x0e\x14\x01\0\x10\0\0\0\x52\x02\0\0\
\x32\x03\0\0\x0e\x34\x01\0\x18\0\0\0\x52\x02\0\0\x44\x03\0\0\x0e\x38\x01\0\x28\
\0\0\0\x52\x02\0\0\x68\x03\0\0\x1b\x2c\x01\0\x30\0\0\0\x52\x02\0\0\x8b\x03\0\0\
\x0f\x30\x01\0\x50\0\0\0\x52\x02\0\0\x44\x03\0\0\x1f\x38\x01\0\x58\0\0\0\x52\
\x02\0\0\x9f\x03\0\0\x0f\x3c\x01\0\x60\0\0\0\x52\x02\0\0\xb3\x03\0\0\x11\x50\
\x01\0\x70\0\0\0\x52\x02\0\0\xb3\x03\0\0\x0f\x50\x01\0\x78\0\0\0\x52\x02\0\0\
\xd4\x03\0\0\x0f\x54\x01\0\x80\0\0\0\x52\x02\0\0\xd4\x03\0\0\x0d\x54\x01\0\x90\
\0\0\0\x52\x02\0\0\xea\x03\0\0\x10\x58\x01\0\x98\0\0\0\x52\x02\0\0\xea\x03\0\0\
\x0e\x58\x01\0\xd0\0\0\0\x52\x02\0\0\x02\x04\0\0\x02\x60\x01\0\xe0\0\0\0\x52\
\x02\0\0\x53\x04\0\0\x0b\x64\x01\0\x08\x01\0\0\x52\x02\0\0\x63\x04\0\0\x3a\x70\
\x01\0\x18\x01\0\0\x52\x02\0\0\x63\x04\0\0\x02\x70\x01\0\x28\x01\0\0\x52\x02\0\
\0\xa3\x04\0\0\x02\x78\x01\0\x58\x01\0\0\x52\x02\0\0\xdc\x04\0\0\x02\x7c\x01\0\
\x98\x01\0\0\x52\x02\0\0\x0e\x05\0\0\x02\x84\x01\0\xc0\x01\0\0\x52\x02\0\0\x4d\
\x05\0\0\x02\x88\x01\0\xf8\x01\0\0\x52\x02\0\0\x84\x05\0\0\x02\x90\x01\0\x28\
\x02\0\0\x52\x02\0\0\xc2\x05\0\0\x11\x98\x01\0\x58\x02\0\0\x52\x02\0\0\x09\x06\
\0\0\x02\xac\x01\0\x90\x02\0\0\x52\x02\0\0\xd7\x02\0\0\x05\xf4\0\0\x11\x08\0\0\
\x06\0\0\0\0\0\0\0\x52\x02\0\0\x50\x06\0\0\x05\xd8\x01\0\x10\0\0\0\x52\x02\0\0\
\xa1\x06\0\0\x12\xf4\x01\0\x18\0\0\0\x52\x02\0\0\xbb\x06\0\0\x0e\xf0\x01\0\x20\
\0\0\0\x52\x02\0\0\xcd\x06\0\0\x10\x04\x02\0\x30\0\0\0\x52\x02\0\0\xed\x06\0\0\
\x18\x0c\x02\0\x48\0\0\0\x52\x02\0\0\x50\x06\0\0\x05\xd8\x01\0\x27\x08\0\0\x07\
\0\0\0\0\0\0\0\x52\x02\0\0\x0c\x07\0\0\x05\x20\x02\0\x10\0\0\0\x52\x02\0\0\xa1\
\x06\0\0\x12\x3c\x02\0\x18\0\0\0\x52\x02\0\0\xbb\x06\0\0\x0e\x38\x02\0\x20\0\0\
\0\x52\x02\0\0\x0c\x07\0\0\x05\x20\x02\0\x30\0\0\0\x52\x02\0\0\x5c\x07\0\0\x10\
\x54\x02\0\x48\0\0\0\x52\x02\0\0\x9d\x07\0\0\x17\x5c\x02\0\x60\0\0\0\x52\x02\0\
\0\x0c\x07\0\0\x05\x20\x02\0\x10\0\0\0\0\x08\0\0\x0b\0\0\0\x10\0\0\0\x0c\0\0\0\
\xbb\x07\0\0\0\0\0\0\x18\0\0\0\x1a\0\0\0\xbf\x07\0\0\0\0\0\0\x20\0\0\0\x0c\0\0\
\0\xc3\x07\0\0\0\0\0\0\x28\0\0\0\x0c\0\0\0\xc7\x07\0\0\0\0\0\0\x38\0\0\0\x0c\0\
\0\0\xcf\x07\0\0\0\0\0\0\x50\0\0\0\x1c\0\0\0\xd3\x07\0\0\0\0\0\0\x58\0\0\0\x1d\
\0\0\0\xbf\x07\0\0\0\0\0\0\x68\0\0\0\x1a\0\0\0\xd9\x07\0\0\0\0\0\0\xa8\0\0\0\
\x0c\0\0\0\xdd\x07\0\0\0\0\0\0\x58\x01\0\0\x0c\0\0\0\xd9\x07\0\0\0\0\0\0\x98\
\x01\0\0\x0c\0\0\0\xe1\x07\0\0\0\0\0\0\x11\x08\0\0\x02\0\0\0\x10\0\0\0\x1a\0\0\
\0\xd9\x07\0\0\0\0\0\0\x18\0\0\0\x0c\0\0\0\xd9\x07\0\0\0\0\0\0\x27\x08\0\0\x02\
\0\0\0\x10\0\0\0\x1a\0\0\0\xd9\x07\0\0\0\0\0\0\x18\0\0\0\x0c\0\0\0\xd9\x07\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\
\x03\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\xb6\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xf8\x01\0\0\0\0\0\0\x98\x01\0\0\0\0\0\0\x01\0\0\0\
\0\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x11\0\0\0\x01\0\0\0\x06\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x90\x03\0\0\0\0\0\0\xa0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x22\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x30\x06\0\0\0\0\0\0\x58\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x38\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x88\
\x06\0\0\0\0\0\0\x70\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x4d\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xf8\x06\0\0\0\0\0\
\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x55\0\0\
\0\x08\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xfc\x06\0\0\0\0\0\0\x02\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x5a\0\0\0\x01\0\0\0\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x60\0\0\0\x01\0\0\0\x02\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x18\x07\0\0\0\0\0\0\x91\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x60\x01\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\xb0\x07\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\x02\0\0\0\x03\0\0\0\x08\0\0\0\0\0\
\0\0\x10\0\0\0\0\0\0\0\x75\x01\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x10\x08\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x08\0\0\0\0\0\0\0\
\x10\0\0\0\0\0\0\0\x8f\x01\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x20\
\x08\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x02\0\0\0\x05\0\0\0\x08\0\0\0\0\0\0\0\x10\0\
\0\0\0\0\0\0\xa8\x01\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\x08\0\0\
\0\0\0\0\0\x0d\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xad\x01\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\x15\0\0\0\0\0\0\xec\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0";

	*sz = sizeof(data) - 1;
	return (const void *)data;
}

#ifdef __cplusplus
struct kfree_skb *kfree_skb::open(const struct bpf_object_open_opts *opts) { return kfree_skb__open_opts(opts); }
struct kfree_skb *kfree_skb::open_and_load() { return kfree_skb__open_and_load(); }
int kfree_skb::load(struct kfree_skb *skel) { return kfree_skb__load(skel); }
int kfree_skb::attach(struct kfree_skb *skel) { return kfree_skb__attach(skel); }
void kfree_skb::detach(struct kfree_skb *skel) { kfree_skb__detach(skel); }
void kfree_skb::destroy(struct kfree_skb *skel) { kfree_skb__destroy(skel); }
const void *kfree_skb::elf_bytes(size_t *sz) { return kfree_skb__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
kfree_skb__assert(struct kfree_skb *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->bss->result) == 2, "unexpected size of 'result'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __KFREE_SKB_SKEL_H__ */
