/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED BY BPFTOOL! */
#ifndef __CB_REFS_SKEL_H__
#define __CB_REFS_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

#define BPF_SKEL_SUPPORTS_MAP_AUTO_ATTACH 1

struct cb_refs {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *array_map;
	} maps;
	struct {
		struct bpf_program *underflow_prog;
		struct bpf_program *leak_prog;
		struct bpf_program *nested_cb;
		struct bpf_program *non_cb_transfer_ref;
	} progs;
	struct {
		struct bpf_link *underflow_prog;
		struct bpf_link *leak_prog;
		struct bpf_link *nested_cb;
		struct bpf_link *non_cb_transfer_ref;
	} links;

#ifdef __cplusplus
	static inline struct cb_refs *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct cb_refs *open_and_load();
	static inline int load(struct cb_refs *skel);
	static inline int attach(struct cb_refs *skel);
	static inline void detach(struct cb_refs *skel);
	static inline void destroy(struct cb_refs *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
cb_refs__destroy(struct cb_refs *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
cb_refs__create_skeleton(struct cb_refs *obj);

static inline struct cb_refs *
cb_refs__open_opts(const struct bpf_object_open_opts *opts)
{
	struct cb_refs *obj;
	int err;

	obj = (struct cb_refs *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = cb_refs__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	cb_refs__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct cb_refs *
cb_refs__open(void)
{
	return cb_refs__open_opts(NULL);
}

static inline int
cb_refs__load(struct cb_refs *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct cb_refs *
cb_refs__open_and_load(void)
{
	struct cb_refs *obj;
	int err;

	obj = cb_refs__open();
	if (!obj)
		return NULL;
	err = cb_refs__load(obj);
	if (err) {
		cb_refs__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
cb_refs__attach(struct cb_refs *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
cb_refs__detach(struct cb_refs *obj)
{
	bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *cb_refs__elf_bytes(size_t *sz);

static inline int
cb_refs__create_skeleton(struct cb_refs *obj)
{
	struct bpf_object_skeleton *s;
	struct bpf_map_skeleton *map __attribute__((unused));
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "cb_refs";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 1;
	s->map_skel_sz = 24;
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt,
			sizeof(*s->maps) > 24 ? sizeof(*s->maps) : 24);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	map = (struct bpf_map_skeleton *)((char *)s->maps + 0 * s->map_skel_sz);
	map->name = "array_map";
	map->map = &obj->maps.array_map;

	/* programs */
	s->prog_cnt = 4;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "underflow_prog";
	s->progs[0].prog = &obj->progs.underflow_prog;
	s->progs[0].link = &obj->links.underflow_prog;

	s->progs[1].name = "leak_prog";
	s->progs[1].prog = &obj->progs.leak_prog;
	s->progs[1].link = &obj->links.leak_prog;

	s->progs[2].name = "nested_cb";
	s->progs[2].prog = &obj->progs.nested_cb;
	s->progs[2].link = &obj->links.nested_cb;

	s->progs[3].name = "non_cb_transfer_ref";
	s->progs[3].prog = &obj->progs.non_cb_transfer_ref;
	s->progs[3].link = &obj->links.non_cb_transfer_ref;

	s->data = cb_refs__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *cb_refs__elf_bytes(size_t *sz)
{
	static const char data[] __attribute__((__aligned__(8))) = "\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x40\x14\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0b\0\
\x01\0\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x2e\x74\
\x65\x78\x74\0\x3f\x74\x63\0\x2e\x6d\x61\x70\x73\0\x6c\x69\x63\x65\x6e\x73\x65\
\0\x63\x62\x5f\x72\x65\x66\x73\x2e\x63\0\x63\x62\x31\0\x63\x62\x32\0\x63\x62\
\x33\0\x63\x62\0\x75\x6e\x64\x65\x72\x66\x6c\x6f\x77\x5f\x70\x72\x6f\x67\0\x62\
\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x74\x65\x73\x74\x5f\
\x61\x63\x71\x75\x69\x72\x65\0\x61\x72\x72\x61\x79\x5f\x6d\x61\x70\0\x62\x70\
\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x74\x65\x73\x74\x5f\x72\
\x65\x6c\x65\x61\x73\x65\0\x6c\x65\x61\x6b\x5f\x70\x72\x6f\x67\0\x6e\x65\x73\
\x74\x65\x64\x5f\x63\x62\0\x6e\x6f\x6e\x5f\x63\x62\x5f\x74\x72\x61\x6e\x73\x66\
\x65\x72\x5f\x72\x65\x66\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\
\x2e\x74\x65\x78\x74\0\x2e\x72\x65\x6c\x3f\x74\x63\0\x2e\x42\x54\x46\0\x2e\x42\
\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x29\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x33\0\0\0\x02\0\x03\0\0\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x37\0\0\0\x02\
\0\x03\0\x20\0\0\0\0\0\0\0\x48\0\0\0\0\0\0\0\x3b\0\0\0\x02\0\x03\0\x68\0\0\0\0\
\0\0\0\x78\0\0\0\0\0\0\0\x3f\0\0\0\x02\0\x03\0\xe0\0\0\0\0\0\0\0\x10\0\0\0\0\0\
\0\0\x42\0\0\0\x12\0\x04\0\0\0\0\0\0\0\0\0\x98\0\0\0\0\0\0\0\x51\0\0\0\x10\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x6d\0\0\0\x11\0\x05\0\0\0\0\0\0\0\0\0\x20\0\
\0\0\0\0\0\0\x77\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x93\0\0\0\x12\
\0\x04\0\x98\0\0\0\0\0\0\0\xd8\0\0\0\0\0\0\0\x9d\0\0\0\x12\0\x04\0\x70\x01\0\0\
\0\0\0\0\xa0\0\0\0\0\0\0\0\xa7\0\0\0\x12\0\x04\0\x10\x02\0\0\0\0\0\0\x78\0\0\0\
\0\0\0\0\xbb\0\0\0\x11\0\x06\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x79\x41\0\0\0\
\0\0\0\x85\x10\0\0\xff\xff\xff\xff\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xbf\x46\
\0\0\0\0\0\0\xb7\x01\0\0\0\0\0\0\x7b\x1a\xf8\xff\0\0\0\0\xbf\xa1\0\0\0\0\0\0\
\x07\x01\0\0\xf8\xff\xff\xff\x85\x10\0\0\xff\xff\xff\xff\x7b\x06\0\0\0\0\0\0\
\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb7\x01\0\0\0\0\0\0\x7b\x1a\xf8\xff\0\0\0\
\0\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\xf8\xff\xff\xff\x85\x10\0\0\xff\xff\xff\xff\
\xbf\xa3\0\0\0\0\0\0\x07\x03\0\0\xf0\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x18\x02\0\0\xe0\0\0\0\0\0\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\xa4\
\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\
\xb7\x01\0\0\0\0\0\0\x7b\x1a\xf0\xff\0\0\0\0\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\
\xf0\xff\xff\xff\x85\x10\0\0\xff\xff\xff\xff\x7b\x0a\xf8\xff\0\0\0\0\x15\0\x0a\
\0\0\0\0\0\xbf\xa3\0\0\0\0\0\0\x07\x03\0\0\xf8\xff\xff\xff\x18\x01\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\
\0\0\xa4\0\0\0\x79\xa1\xf8\xff\0\0\0\0\x85\x10\0\0\xff\xff\xff\xff\xb7\0\0\0\0\
\0\0\0\x95\0\0\0\0\0\0\0\xb7\x07\0\0\0\0\0\0\x63\x7a\xf4\xff\0\0\0\0\xbf\xa2\0\
\0\0\0\0\0\x07\x02\0\0\xf4\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\
\0\0\0\x01\0\0\0\xbf\x06\0\0\0\0\0\0\x15\x06\x10\0\0\0\0\0\x7b\x7a\xf8\xff\0\0\
\0\0\xbf\xa3\0\0\0\0\0\0\x07\x03\0\0\xf8\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x18\x02\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\
\xa4\0\0\0\x79\xa2\xf8\xff\0\0\0\0\xbf\x61\0\0\0\0\0\0\x85\0\0\0\xc2\0\0\0\x7b\
\x0a\xf8\xff\0\0\0\0\x15\0\x02\0\0\0\0\0\xbf\x01\0\0\0\0\0\0\x85\x10\0\0\xff\
\xff\xff\xff\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb7\x01\0\0\0\0\0\0\x7b\x1a\
\xf8\xff\0\0\0\0\x63\x1a\xf4\xff\0\0\0\0\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\xf8\
\xff\xff\xff\x85\x10\0\0\xff\xff\xff\xff\xbf\x06\0\0\0\0\0\0\x15\x06\x0a\0\0\0\
\0\0\xbf\xa3\0\0\0\0\0\0\x07\x03\0\0\xf4\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x18\x02\0\0\x68\0\0\0\0\0\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\
\xa4\0\0\0\xbf\x61\0\0\0\0\0\0\x85\x10\0\0\xff\xff\xff\xff\xb7\0\0\0\0\0\0\0\
\x95\0\0\0\0\0\0\0\xb7\x01\0\0\0\0\0\0\x7b\x1a\xf0\xff\0\0\0\0\xbf\xa1\0\0\0\0\
\0\0\x07\x01\0\0\xf0\xff\xff\xff\x85\x10\0\0\xff\xff\xff\xff\x7b\x0a\xf8\xff\0\
\0\0\0\x15\0\x06\0\0\0\0\0\xbf\xa4\0\0\0\0\0\0\x07\x04\0\0\xf8\xff\xff\xff\x85\
\x10\0\0\xff\xff\xff\xff\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\xf0\xff\xff\xff\x85\
\x10\0\0\xff\xff\xff\xff\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x47\x50\x4c\0\0\0\0\0\x08\0\0\0\
\0\0\0\0\x0a\0\0\0\x0b\0\0\0\x48\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x88\0\0\0\0\
\0\0\0\x0a\0\0\0\x09\0\0\0\xa0\0\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\xb0\0\0\0\0\0\
\0\0\x01\0\0\0\x02\0\0\0\x20\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x48\0\0\0\0\0\0\
\0\x01\0\0\0\x0a\0\0\0\x58\0\0\0\0\0\0\0\x01\0\0\0\x02\0\0\0\x80\0\0\0\0\0\0\0\
\x0a\0\0\0\x0b\0\0\0\xb8\0\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\xf8\0\0\0\0\0\0\0\
\x01\0\0\0\x0a\0\0\0\x08\x01\0\0\0\0\0\0\x01\0\0\0\x02\0\0\0\x58\x01\0\0\0\0\0\
\0\x0a\0\0\0\x0b\0\0\0\x98\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xc0\x01\0\0\0\0\
\0\0\x01\0\0\0\x0a\0\0\0\xd0\x01\0\0\0\0\0\0\x01\0\0\0\x02\0\0\0\xf8\x01\0\0\0\
\0\0\0\x0a\0\0\0\x0b\0\0\0\x30\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x58\x02\0\0\
\0\0\0\0\x0a\0\0\0\x02\0\0\0\x70\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x9f\xeb\
\x01\0\x18\0\0\0\0\0\0\0\x68\x03\0\0\x68\x03\0\0\x7d\x05\0\0\0\0\0\0\0\0\0\x02\
\x03\0\0\0\x01\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\
\x02\0\0\0\x04\0\0\0\x02\0\0\0\x05\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\
\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x07\0\0\0\x19\0\0\0\x01\0\0\x04\x08\0\0\
\0\x23\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x29\0\0\0\0\0\0\0\0\0\0\x02\
\x0a\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x10\0\0\0\0\0\0\0\x04\
\0\0\x04\x20\0\0\0\x27\0\0\0\x01\0\0\0\0\0\0\0\x2c\0\0\0\x05\0\0\0\x40\0\0\0\
\x30\0\0\0\x06\0\0\0\x80\0\0\0\x36\0\0\0\x09\0\0\0\xc0\0\0\0\x42\0\0\0\0\0\0\
\x0e\x0b\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\x01\0\0\x0d\x02\0\0\
\0\x4c\0\0\0\x0d\0\0\0\x50\0\0\0\x01\0\0\x0c\x0e\0\0\0\0\0\0\0\x01\0\0\x0d\x11\
\0\0\0\0\0\0\0\x19\0\0\0\0\0\0\0\0\0\0\x02\x12\0\0\0\x5f\0\0\0\x05\0\0\x04\x20\
\0\0\0\x73\0\0\0\x02\0\0\0\0\0\0\0\x75\0\0\0\x02\0\0\0\x20\0\0\0\x77\0\0\0\x13\
\0\0\0\x40\0\0\0\x7c\0\0\0\x11\0\0\0\x80\0\0\0\x81\0\0\0\x15\0\0\0\xc0\0\0\0\
\x85\0\0\0\x02\0\0\x04\x08\0\0\0\x96\0\0\0\x14\0\0\0\0\0\0\0\x98\0\0\0\x02\0\0\
\0\x20\0\0\0\x9a\0\0\0\x01\0\0\x04\x04\0\0\0\x73\0\0\0\x02\0\0\0\0\0\0\0\xac\0\
\0\0\0\0\0\x08\x16\0\0\0\xb7\0\0\0\x01\0\0\x04\x04\0\0\0\xc7\0\0\0\x17\0\0\0\0\
\0\0\0\xcc\0\0\0\0\0\0\x08\x18\0\0\0\0\0\0\0\x01\0\0\x04\x04\0\0\0\xd5\0\0\0\
\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x1a\0\0\0\xdd\0\0\0\0\0\0\x01\x08\0\0\0\
\x40\0\0\0\xeb\0\0\0\x02\0\0\x0c\x10\0\0\0\0\0\0\0\x01\0\0\x0d\0\0\0\0\0\0\0\0\
\x11\0\0\0\x07\x01\0\0\x02\0\0\x0c\x1c\0\0\0\0\0\0\0\x04\0\0\x0d\x02\0\0\0\x23\
\x01\0\0\x0d\0\0\0\x2c\0\0\0\x0d\0\0\0\x30\0\0\0\x0d\0\0\0\x4c\0\0\0\x0d\0\0\0\
\x27\x01\0\0\0\0\0\x0c\x1e\0\0\0\x2b\x01\0\0\x01\0\0\x0c\x0e\0\0\0\x35\x01\0\0\
\0\0\0\x0c\x1e\0\0\0\x39\x01\0\0\x01\0\0\x0c\x0e\0\0\0\x43\x01\0\0\0\0\0\x0c\
\x1e\0\0\0\x47\x01\0\0\x01\0\0\x0c\x0e\0\0\0\x5b\x01\0\0\0\0\0\x0c\x1e\0\0\0\
\x5e\x01\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\x26\0\0\
\0\x04\0\0\0\x04\0\0\0\x63\x01\0\0\0\0\0\x0e\x27\0\0\0\x01\0\0\0\x6c\x01\0\0\0\
\0\0\x12\x12\0\0\0\x5e\x05\0\0\x01\0\0\x0f\x20\0\0\0\x0c\0\0\0\0\0\0\0\x20\0\0\
\0\x64\x05\0\0\x01\0\0\x0f\x04\0\0\0\x28\0\0\0\0\0\0\0\x04\0\0\0\x6c\x05\0\0\
\x02\0\0\x0f\0\0\0\0\x1b\0\0\0\0\0\0\0\0\0\0\0\x1d\0\0\0\0\0\0\0\0\0\0\0\0\x69\
\x6e\x74\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\
\x5f\x5f\0\x6d\x61\x70\x5f\x76\x61\x6c\x75\x65\0\x70\x74\x72\0\x74\x79\x70\x65\
\0\x6b\x65\x79\0\x76\x61\x6c\x75\x65\0\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\x65\
\x73\0\x61\x72\x72\x61\x79\x5f\x6d\x61\x70\0\x63\x74\x78\0\x75\x6e\x64\x65\x72\
\x66\x6c\x6f\x77\x5f\x70\x72\x6f\x67\0\x70\x72\x6f\x67\x5f\x74\x65\x73\x74\x5f\
\x72\x65\x66\x5f\x6b\x66\x75\x6e\x63\0\x61\0\x62\0\x6d\x65\x6d\x62\0\x6e\x65\
\x78\x74\0\x63\x6e\x74\0\x70\x72\x6f\x67\x5f\x74\x65\x73\x74\x5f\x6d\x65\x6d\
\x62\x65\x72\0\x6d\0\x63\0\x70\x72\x6f\x67\x5f\x74\x65\x73\x74\x5f\x6d\x65\x6d\
\x62\x65\x72\x31\0\x72\x65\x66\x63\x6f\x75\x6e\x74\x5f\x74\0\x72\x65\x66\x63\
\x6f\x75\x6e\x74\x5f\x73\x74\x72\x75\x63\x74\0\x72\x65\x66\x73\0\x61\x74\x6f\
\x6d\x69\x63\x5f\x74\0\x63\x6f\x75\x6e\x74\x65\x72\0\x75\x6e\x73\x69\x67\x6e\
\x65\x64\x20\x6c\x6f\x6e\x67\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\
\x6c\x6c\x5f\x74\x65\x73\x74\x5f\x61\x63\x71\x75\x69\x72\x65\0\x62\x70\x66\x5f\
\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x74\x65\x73\x74\x5f\x72\x65\x6c\
\x65\x61\x73\x65\0\x6d\x61\x70\0\x63\x62\x31\0\x6c\x65\x61\x6b\x5f\x70\x72\x6f\
\x67\0\x63\x62\x32\0\x6e\x65\x73\x74\x65\x64\x5f\x63\x62\0\x63\x62\x33\0\x6e\
\x6f\x6e\x5f\x63\x62\x5f\x74\x72\x61\x6e\x73\x66\x65\x72\x5f\x72\x65\x66\0\x63\
\x62\0\x63\x68\x61\x72\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x6b\x70\x74\x72\0\
\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\
\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x36\x2e\x31\x32\x2e\x30\x2d\x35\x35\
\x2e\x31\x32\x2e\x31\x2e\x65\x6c\x31\x30\x5f\x30\x2f\x6c\x69\x6e\x75\x78\x2d\
\x36\x2e\x31\x32\x2e\x30\x2d\x35\x35\x2e\x31\x32\x2e\x31\x2e\x65\x6c\x31\x30\
\x5f\x30\x2e\x70\x70\x63\x36\x34\x6c\x65\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\
\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\
\x2f\x70\x72\x6f\x67\x73\x2f\x63\x62\x5f\x72\x65\x66\x73\x2e\x63\0\x09\x76\x6f\
\x69\x64\x20\x2a\x70\x20\x3d\x20\x2a\x28\x76\x6f\x69\x64\x20\x2a\x2a\x29\x63\
\x74\x78\x3b\0\x09\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\
\x74\x65\x73\x74\x5f\x72\x65\x6c\x65\x61\x73\x65\x28\x70\x29\x3b\0\x09\x72\x65\
\x74\x75\x72\x6e\x20\x30\x3b\0\x73\x74\x61\x74\x69\x63\x20\x5f\x5f\x61\x6c\x77\
\x61\x79\x73\x5f\x69\x6e\x6c\x69\x6e\x65\x20\x69\x6e\x74\x20\x63\x62\x32\x28\
\x76\x6f\x69\x64\x20\x2a\x6d\x61\x70\x2c\x20\x76\x6f\x69\x64\x20\x2a\x6b\x65\
\x79\x2c\x20\x76\x6f\x69\x64\x20\x2a\x76\x61\x6c\x75\x65\x2c\x20\x76\x6f\x69\
\x64\x20\x2a\x63\x74\x78\x29\0\x09\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\
\x6e\x67\x20\x73\x6c\x20\x3d\x20\x30\x3b\0\x09\x2a\x28\x76\x6f\x69\x64\x20\x2a\
\x2a\x29\x63\x74\x78\x20\x3d\x20\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\
\x61\x6c\x6c\x5f\x74\x65\x73\x74\x5f\x61\x63\x71\x75\x69\x72\x65\x28\x26\x73\
\x6c\x29\x3b\0\x73\x74\x61\x74\x69\x63\x20\x5f\x5f\x61\x6c\x77\x61\x79\x73\x5f\
\x69\x6e\x6c\x69\x6e\x65\x20\x69\x6e\x74\x20\x63\x62\x33\x28\x76\x6f\x69\x64\
\x20\x2a\x6d\x61\x70\x2c\x20\x76\x6f\x69\x64\x20\x2a\x6b\x65\x79\x2c\x20\x76\
\x6f\x69\x64\x20\x2a\x76\x61\x6c\x75\x65\x2c\x20\x76\x6f\x69\x64\x20\x2a\x63\
\x74\x78\x29\0\x09\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\
\x74\x65\x73\x74\x5f\x61\x63\x71\x75\x69\x72\x65\x28\x26\x73\x6c\x29\x3b\0\x09\
\x62\x70\x66\x5f\x66\x6f\x72\x5f\x65\x61\x63\x68\x5f\x6d\x61\x70\x5f\x65\x6c\
\x65\x6d\x28\x26\x61\x72\x72\x61\x79\x5f\x6d\x61\x70\x2c\x20\x63\x62\x2c\x20\
\x26\x70\x2c\x20\x30\x29\x3b\0\x69\x6e\x74\x20\x75\x6e\x64\x65\x72\x66\x6c\x6f\
\x77\x5f\x70\x72\x6f\x67\x28\x76\x6f\x69\x64\x20\x2a\x63\x74\x78\x29\0\x09\x70\
\x20\x3d\x20\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x74\
\x65\x73\x74\x5f\x61\x63\x71\x75\x69\x72\x65\x28\x26\x73\x6c\x29\x3b\0\x09\x69\
\x66\x20\x28\x21\x70\x29\0\x09\x62\x70\x66\x5f\x66\x6f\x72\x5f\x65\x61\x63\x68\
\x5f\x6d\x61\x70\x5f\x65\x6c\x65\x6d\x28\x26\x61\x72\x72\x61\x79\x5f\x6d\x61\
\x70\x2c\x20\x63\x62\x31\x2c\x20\x26\x70\x2c\x20\x30\x29\x3b\0\x7d\0\x69\x6e\
\x74\x20\x6c\x65\x61\x6b\x5f\x70\x72\x6f\x67\x28\x76\x6f\x69\x64\x20\x2a\x63\
\x74\x78\x29\0\x09\x76\x20\x3d\x20\x62\x70\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\
\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x61\x72\x72\x61\x79\x5f\x6d\x61\x70\
\x2c\x20\x26\x28\x69\x6e\x74\x29\x7b\x30\x7d\x29\x3b\0\x09\x69\x66\x20\x28\x21\
\x76\x29\0\x09\x70\x20\x3d\x20\x4e\x55\x4c\x4c\x3b\0\x09\x62\x70\x66\x5f\x66\
\x6f\x72\x5f\x65\x61\x63\x68\x5f\x6d\x61\x70\x5f\x65\x6c\x65\x6d\x28\x26\x61\
\x72\x72\x61\x79\x5f\x6d\x61\x70\x2c\x20\x63\x62\x32\x2c\x20\x26\x70\x2c\x20\
\x30\x29\x3b\0\x09\x70\x20\x3d\x20\x62\x70\x66\x5f\x6b\x70\x74\x72\x5f\x78\x63\
\x68\x67\x28\x26\x76\x2d\x3e\x70\x74\x72\x2c\x20\x70\x29\x3b\0\x09\x69\x66\x20\
\x28\x70\x29\0\x09\x09\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\
\x5f\x74\x65\x73\x74\x5f\x72\x65\x6c\x65\x61\x73\x65\x28\x70\x29\x3b\0\x69\x6e\
\x74\x20\x6e\x65\x73\x74\x65\x64\x5f\x63\x62\x28\x76\x6f\x69\x64\x20\x2a\x63\
\x74\x78\x29\0\x09\x69\x6e\x74\x20\x73\x70\x20\x3d\x20\x30\x3b\0\x09\x62\x70\
\x66\x5f\x66\x6f\x72\x5f\x65\x61\x63\x68\x5f\x6d\x61\x70\x5f\x65\x6c\x65\x6d\
\x28\x26\x61\x72\x72\x61\x79\x5f\x6d\x61\x70\x2c\x20\x63\x62\x33\x2c\x20\x26\
\x73\x70\x2c\x20\x30\x29\x3b\0\x69\x6e\x74\x20\x6e\x6f\x6e\x5f\x63\x62\x5f\x74\
\x72\x61\x6e\x73\x66\x65\x72\x5f\x72\x65\x66\x28\x76\x6f\x69\x64\x20\x2a\x63\
\x74\x78\x29\0\x09\x63\x62\x31\x28\x4e\x55\x4c\x4c\x2c\x20\x4e\x55\x4c\x4c\x2c\
\x20\x4e\x55\x4c\x4c\x2c\x20\x26\x70\x29\x3b\0\x2e\x6d\x61\x70\x73\0\x6c\x69\
\x63\x65\x6e\x73\x65\0\x2e\x6b\x73\x79\x6d\x73\0\x2e\x74\x65\x78\x74\0\x3f\x74\
\x63\0\0\0\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x54\0\0\0\x54\0\0\0\x44\x03\0\0\
\x98\x03\0\0\0\0\0\0\x08\0\0\0\x73\x05\0\0\x04\0\0\0\0\0\0\0\x1f\0\0\0\x20\0\0\
\0\x21\0\0\0\x68\0\0\0\x23\0\0\0\xe0\0\0\0\x25\0\0\0\x79\x05\0\0\x04\0\0\0\0\0\
\0\0\x0f\0\0\0\x98\0\0\0\x20\0\0\0\x70\x01\0\0\x22\0\0\0\x10\x02\0\0\x24\0\0\0\
\x10\0\0\0\x73\x05\0\0\x0e\0\0\0\0\0\0\0\x71\x01\0\0\xf4\x01\0\0\x0c\x50\0\0\
\x08\0\0\0\x71\x01\0\0\x0e\x02\0\0\x02\x54\0\0\x10\0\0\0\x71\x01\0\0\x2f\x02\0\
\0\x02\x5c\0\0\x20\0\0\0\x71\x01\0\0\x3a\x02\0\0\0\xa0\0\0\x30\0\0\0\x71\x01\0\
\0\x87\x02\0\0\x10\xa8\0\0\x48\0\0\0\x71\x01\0\0\x9e\x02\0\0\x12\xb0\0\0\x50\0\
\0\0\x71\x01\0\0\x9e\x02\0\0\x10\xb0\0\0\x58\0\0\0\x71\x01\0\0\x2f\x02\0\0\x02\
\xb8\0\0\x68\0\0\0\x71\x01\0\0\xd1\x02\0\0\0\x20\x01\0\x70\0\0\0\x71\x01\0\0\
\x87\x02\0\0\x10\x28\x01\0\x88\0\0\0\x71\x01\0\0\x1e\x03\0\0\x02\x34\x01\0\xa0\
\0\0\0\x71\x01\0\0\x41\x03\0\0\x02\x38\x01\0\xd0\0\0\0\x71\x01\0\0\x2f\x02\0\0\
\x02\x48\x01\0\xe0\0\0\0\x71\x01\0\0\x2f\x02\0\0\x02\x14\x01\0\x79\x05\0\0\x25\
\0\0\0\0\0\0\0\x71\x01\0\0\x70\x03\0\0\0\x6c\0\0\x08\0\0\0\x71\x01\0\0\x87\x02\
\0\0\x10\x78\0\0\x20\0\0\0\x71\x01\0\0\x8e\x03\0\0\x06\x80\0\0\x28\0\0\0\x71\
\x01\0\0\x8e\x03\0\0\x04\x80\0\0\x30\0\0\0\x71\x01\0\0\xb5\x03\0\0\x06\x84\0\0\
\x48\0\0\0\x71\x01\0\0\xbe\x03\0\0\x02\x8c\0\0\x78\0\0\0\x71\x01\0\0\x0e\x02\0\
\0\x1e\x90\0\0\x80\0\0\0\x71\x01\0\0\x0e\x02\0\0\x02\x90\0\0\x88\0\0\0\x71\x01\
\0\0\xee\x03\0\0\x01\x98\0\0\x98\0\0\0\x71\x01\0\0\xf0\x03\0\0\0\xc8\0\0\xa0\0\
\0\0\x71\x01\0\0\x09\x04\0\0\x27\xdc\0\0\xb8\0\0\0\x71\x01\0\0\x09\x04\0\0\x06\
\xdc\0\0\xd8\0\0\0\x71\x01\0\0\x3a\x04\0\0\x06\xe0\0\0\xe0\0\0\0\x71\x01\0\0\
\x43\x04\0\0\x04\xec\0\0\xf8\0\0\0\x71\x01\0\0\x4e\x04\0\0\x02\xf0\0\0\x28\x01\
\0\0\x71\x01\0\0\x7e\x04\0\0\x1d\xf4\0\0\x30\x01\0\0\x71\x01\0\0\x7e\x04\0\0\
\x06\xf4\0\0\x40\x01\0\0\x71\x01\0\0\x7e\x04\0\0\x04\xf4\0\0\x48\x01\0\0\x71\
\x01\0\0\x9e\x04\0\0\x06\xf8\0\0\x50\x01\0\0\x71\x01\0\0\xa6\x04\0\0\x03\xfc\0\
\0\x60\x01\0\0\x71\x01\0\0\xee\x03\0\0\x01\x04\x01\0\x70\x01\0\0\x71\x01\0\0\
\xc8\x04\0\0\0\x58\x01\0\x78\x01\0\0\x71\x01\0\0\x87\x02\0\0\x10\x64\x01\0\x80\
\x01\0\0\x71\x01\0\0\xe1\x04\0\0\x06\x68\x01\0\x98\x01\0\0\x71\x01\0\0\x8e\x03\
\0\0\x06\x70\x01\0\xa8\x01\0\0\x71\x01\0\0\xb5\x03\0\0\x06\x74\x01\0\xc0\x01\0\
\0\x71\x01\0\0\xee\x04\0\0\x02\x7c\x01\0\xf0\x01\0\0\x71\x01\0\0\x0e\x02\0\0\
\x02\x80\x01\0\0\x02\0\0\x71\x01\0\0\xee\x03\0\0\x01\x88\x01\0\x10\x02\0\0\x71\
\x01\0\0\x1f\x05\0\0\0\x94\x01\0\x18\x02\0\0\x71\x01\0\0\x87\x02\0\0\x10\xa0\
\x01\0\x30\x02\0\0\x71\x01\0\0\x8e\x03\0\0\x06\xa8\x01\0\x38\x02\0\0\x71\x01\0\
\0\x8e\x03\0\0\x04\xa8\x01\0\x40\x02\0\0\x71\x01\0\0\xb5\x03\0\0\x06\xac\x01\0\
\x58\x02\0\0\x71\x01\0\0\x42\x05\0\0\x02\xb4\x01\0\x70\x02\0\0\x71\x01\0\0\x1e\
\x03\0\0\x02\xb8\x01\0\x78\x02\0\0\x71\x01\0\0\xee\x03\0\0\x01\xc0\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\x20\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\xe4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x28\x01\0\0\0\0\0\0\x80\x01\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\x18\0\0\0\0\0\0\0\x11\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa8\
\x02\0\0\0\0\0\0\xf0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x17\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x98\x03\0\0\0\0\0\
\0\x88\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x1b\0\
\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x20\x06\0\0\0\0\0\0\x20\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x21\0\0\0\x01\0\0\0\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\x06\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc4\0\0\0\x09\0\0\0\x40\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x48\x06\0\0\0\0\0\0\x50\0\0\0\0\0\0\0\x02\0\0\0\x03\0\0\0\
\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xce\0\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x98\x06\0\0\0\0\0\0\xf0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x08\0\0\
\0\0\0\0\0\x10\0\0\0\0\0\0\0\xd6\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x88\x07\0\0\0\0\0\0\xfd\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\xdb\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x88\x10\0\0\
\0\0\0\0\xb8\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0";

	*sz = sizeof(data) - 1;
	return (const void *)data;
}

#ifdef __cplusplus
struct cb_refs *cb_refs::open(const struct bpf_object_open_opts *opts) { return cb_refs__open_opts(opts); }
struct cb_refs *cb_refs::open_and_load() { return cb_refs__open_and_load(); }
int cb_refs::load(struct cb_refs *skel) { return cb_refs__load(skel); }
int cb_refs::attach(struct cb_refs *skel) { return cb_refs__attach(skel); }
void cb_refs::detach(struct cb_refs *skel) { cb_refs__detach(skel); }
void cb_refs::destroy(struct cb_refs *skel) { cb_refs__destroy(skel); }
const void *cb_refs::elf_bytes(size_t *sz) { return cb_refs__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
cb_refs__assert(struct cb_refs *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __CB_REFS_SKEL_H__ */
