/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED BY BPFTOOL! */
#ifndef __PRIV_MAP_SKEL_H__
#define __PRIV_MAP_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

#define BPF_SKEL_SUPPORTS_MAP_AUTO_ATTACH 1

struct priv_map {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *priv_map;
	} maps;

#ifdef __cplusplus
	static inline struct priv_map *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct priv_map *open_and_load();
	static inline int load(struct priv_map *skel);
	static inline int attach(struct priv_map *skel);
	static inline void detach(struct priv_map *skel);
	static inline void destroy(struct priv_map *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
priv_map__destroy(struct priv_map *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
priv_map__create_skeleton(struct priv_map *obj);

static inline struct priv_map *
priv_map__open_opts(const struct bpf_object_open_opts *opts)
{
	struct priv_map *obj;
	int err;

	obj = (struct priv_map *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = priv_map__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	priv_map__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct priv_map *
priv_map__open(void)
{
	return priv_map__open_opts(NULL);
}

static inline int
priv_map__load(struct priv_map *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct priv_map *
priv_map__open_and_load(void)
{
	struct priv_map *obj;
	int err;

	obj = priv_map__open();
	if (!obj)
		return NULL;
	err = priv_map__load(obj);
	if (err) {
		priv_map__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
priv_map__attach(struct priv_map *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
priv_map__detach(struct priv_map *obj)
{
	bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *priv_map__elf_bytes(size_t *sz);

static inline int
priv_map__create_skeleton(struct priv_map *obj)
{
	struct bpf_object_skeleton *s;
	struct bpf_map_skeleton *map __attribute__((unused));
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "priv_map";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 1;
	s->map_skel_sz = 24;
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt,
			sizeof(*s->maps) > 24 ? sizeof(*s->maps) : 24);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	map = (struct bpf_map_skeleton *)((char *)s->maps + 0 * s->map_skel_sz);
	map->name = "priv_map";
	map->map = &obj->maps.priv_map;

	s->data = priv_map__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *priv_map__elf_bytes(size_t *sz)
{
	static const char data[] __attribute__((__aligned__(8))) = "\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xc0\x02\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x06\0\
\x01\0\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x6c\x69\
\x63\x65\x6e\x73\x65\0\x2e\x6d\x61\x70\x73\0\x70\x72\x69\x76\x5f\x6d\x61\x70\
\x2e\x63\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x70\x72\x69\x76\x5f\x6d\x61\x70\0\
\x2e\x42\x54\x46\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x1f\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x2a\0\0\0\x11\0\x03\
\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x33\0\0\0\x11\0\x04\0\0\0\0\0\0\0\0\0\x18\
\0\0\0\0\0\0\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x9f\xeb\x01\0\x18\0\0\0\0\0\0\0\x38\x01\0\0\x38\x01\0\0\x68\0\0\0\0\0\0\
\0\0\0\0\x02\x03\0\0\0\x01\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\0\0\0\0\0\0\0\
\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x16\0\0\0\x05\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\
\0\0\0\0\0\0\0\0\0\x02\x06\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\x02\x08\0\0\0\x19\0\0\0\0\0\0\x08\x09\0\0\0\x1f\0\0\0\
\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\x03\0\0\x04\x18\0\0\0\x2c\0\0\0\x01\0\0\
\0\0\0\0\0\x31\0\0\0\x05\0\0\0\x40\0\0\0\x3d\0\0\0\x07\0\0\0\x80\0\0\0\x43\0\0\
\0\0\0\0\x0e\x0a\0\0\0\x01\0\0\0\x4c\0\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x01\0\0\
\0\0\0\0\0\x03\0\0\0\0\x0c\0\0\0\x04\0\0\0\x04\0\0\0\x51\0\0\0\0\0\0\x0e\x0d\0\
\0\0\x01\0\0\0\x5a\0\0\0\x01\0\0\x0f\x04\0\0\0\x0e\0\0\0\0\0\0\0\x04\0\0\0\x62\
\0\0\0\x01\0\0\x0f\x18\0\0\0\x0b\0\0\0\0\0\0\0\x18\0\0\0\0\x69\x6e\x74\0\x5f\
\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x5f\
\x5f\x75\x33\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x74\x79\
\x70\x65\0\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\x65\x73\0\x76\x61\x6c\x75\x65\0\
\x70\x72\x69\x76\x5f\x6d\x61\x70\0\x63\x68\x61\x72\0\x5f\x6c\x69\x63\x65\x6e\
\x73\x65\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x6d\x61\x70\x73\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x40\0\0\0\0\0\0\0\x41\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x88\0\0\
\0\0\0\0\0\x60\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\
\0\0\x11\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe8\0\0\0\0\0\0\0\
\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x19\0\0\0\
\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xf0\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x3c\0\0\0\x01\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x01\0\0\0\0\0\0\xb8\x01\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0";

	*sz = sizeof(data) - 1;
	return (const void *)data;
}

#ifdef __cplusplus
struct priv_map *priv_map::open(const struct bpf_object_open_opts *opts) { return priv_map__open_opts(opts); }
struct priv_map *priv_map::open_and_load() { return priv_map__open_and_load(); }
int priv_map::load(struct priv_map *skel) { return priv_map__load(skel); }
int priv_map::attach(struct priv_map *skel) { return priv_map__attach(skel); }
void priv_map::detach(struct priv_map *skel) { priv_map__detach(skel); }
void priv_map::destroy(struct priv_map *skel) { priv_map__destroy(skel); }
const void *priv_map::elf_bytes(size_t *sz) { return priv_map__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
priv_map__assert(struct priv_map *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __PRIV_MAP_SKEL_H__ */
